Prior_prob_alpha0 <-
function(a0){
		log(stats::dgamma(a0,1,1))
	}
